==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWidgets/QStyleOptionRubberBand_shell.cpp <==
#include "QStyleOptionRubberBand_shell.h"
#include <QtJambi/Cast>

void deleter_QStyleOptionRubberBand(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStyleOptionRubberBand")
    QStyleOptionRubberBand *_ptr = reinterpret_cast<QStyleOptionRubberBand *>(ptr);
    if(isShell){
        delete static_cast<QStyleOptionRubberBand_shell*>(_ptr);
    }else{
        QtJambiAPI::registerNonShellDeletion(ptr);
        delete _ptr;
    }
}

QtJambiShell* QStyleOptionRubberBand_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QStyleOptionRubberBand_shell) ); }

jmethodID QStyleOptionRubberBand_shell::__shell_javaMethod(int pos) const { return QStyleOptionRubberBand_shell::__shell()->javaMethod(typeid(QStyleOptionRubberBand), pos); }

// emitting (writeShellConstructor)
QStyleOptionRubberBand_shell::QStyleOptionRubberBand_shell()
    : QStyleOptionRubberBand()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStyleOptionRubberBand::QStyleOptionRubberBand_shell()", QStyleOptionRubberBand_shell::__shell())
    QStyleOptionRubberBand_shell::__shell()->constructed(typeid(QStyleOptionRubberBand));
}

QStyleOptionRubberBand_shell::QStyleOptionRubberBand_shell(const QStyleOptionRubberBand& other0)
    : QStyleOptionRubberBand(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStyleOptionRubberBand::QStyleOptionRubberBand_shell(const QStyleOptionRubberBand& other0)", QStyleOptionRubberBand_shell::__shell())
    QStyleOptionRubberBand_shell::__shell()->constructed(typeid(QStyleOptionRubberBand));
}

// emitting (writeShellDestructor)
QStyleOptionRubberBand_shell::~QStyleOptionRubberBand_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QStyleOptionRubberBand::~QStyleOptionRubberBand()", QStyleOptionRubberBand_shell::__shell())
    QStyleOptionRubberBand_shell::__shell()->destructed(typeid(QStyleOptionRubberBand));
}

void QStyleOptionRubberBand_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QStyleOptionRubberBand_shell*>(ptr)->QStyleOptionRubberBand_shell::__shell()->tryDeleteShell(typeid(QStyleOptionRubberBand));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QStyleOptionRubberBand()
void __qt_construct_QStyleOptionRubberBand_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionRubberBand()")
    Q_UNUSED(__java_arguments)
    QStyleOptionRubberBand *__qt_this = new(__qtjambi_ptr) QStyleOptionRubberBand_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QStyleOptionRubberBand(QStyleOptionRubberBand)
void __qt_construct_QStyleOptionRubberBand_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionRubberBand(QStyleOptionRubberBand)")
    jobject other0 = __java_arguments[0].l;
    const QStyleOptionRubberBand& __qt_other0 = qtjambi_cast<const QStyleOptionRubberBand& >(__jni_env, other0);
    QStyleOptionRubberBand *__qt_this = new(__qtjambi_ptr) QStyleOptionRubberBand_shell(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QStyleOptionRubberBand_shell
void __qt_destruct_QStyleOptionRubberBand(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStyleOptionRubberBand")
    reinterpret_cast<QStyleOptionRubberBand_shell*>(ptr)->~QStyleOptionRubberBand_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStyleOptionRubberBand::QStyleOptionRubberBand()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionRubberBand_initialize_1native__Lio_qt_widgets_QStyleOptionRubberBand_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionRubberBand::QStyleOptionRubberBand()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionRubberBand_0, sizeof(QStyleOptionRubberBand_shell), typeid(QStyleOptionRubberBand), true, &deleter_QStyleOptionRubberBand, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStyleOptionRubberBand::QStyleOptionRubberBand(QStyleOptionRubberBand)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionRubberBand_initialize_1native__Lio_qt_widgets_QStyleOptionRubberBand_2Lio_qt_widgets_QStyleOptionRubberBand_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionRubberBand::QStyleOptionRubberBand(QStyleOptionRubberBand)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionRubberBand_1, sizeof(QStyleOptionRubberBand_shell), typeid(QStyleOptionRubberBand), true, &deleter_QStyleOptionRubberBand, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStyleOptionRubberBand::operator=(QStyleOptionRubberBand)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionRubberBand_assign_1native_1cref_1QStyleOptionRubberBand__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QStyleOptionRubberBand *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionRubberBand>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStyleOptionRubberBand::operator=(QStyleOptionRubberBand)", __qt_this)
        const QStyleOptionRubberBand& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QStyleOptionRubberBand>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionRubberBand_setOpaque_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean opaque0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionRubberBand *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionRubberBand>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->opaque = static_cast<bool>(opaque0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionRubberBand_opaque_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionRubberBand *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionRubberBand>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        bool  __qt_value = __qt_this->opaque;
        __java_return_value = jboolean(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionRubberBand_setShape_1native_1cref_1QRubberBand_1Shape__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint shape0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
#if QT_CONFIG(rubberband)
        QStyleOptionRubberBand *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionRubberBand>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QRubberBand::Shape __qt_shape0 = qtjambi_cast<QRubberBand::Shape>(__jni_env, shape0);
        __qt_this->shape = QRubberBand::Shape(__qt_shape0);
#else
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(shape0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif //QT_CONFIG(rubberband)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionRubberBand_shape_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
#if QT_CONFIG(rubberband)
        QStyleOptionRubberBand *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionRubberBand>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QRubberBand::Shape&  __qt_value = __qt_this->shape;
        __java_return_value = __qt_value;
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif //QT_CONFIG(rubberband)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionRubberBand_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStyleOptionRubberBand *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionRubberBand>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStyleOptionRubberBand(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStyleOptionRubberBand>("QStyleOptionRubberBand", "io/qt/widgets/QStyleOptionRubberBand");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStyleOptionRubberBand, {
        ConstructorInfo(&__qt_construct_QStyleOptionRubberBand_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QStyleOptionRubberBand_1, "Lio/qt/widgets/QStyleOptionRubberBand;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStyleOptionRubberBand);
    registerMetaType<QStyleOptionRubberBand>("QStyleOptionRubberBand");
    registerSizeOfShell(typeId, sizeof(QStyleOptionRubberBand_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QStyleOption), typeId, [](void *ptr, qintptr& offset) -> bool {
            QStyleOption *object = reinterpret_cast<QStyleOption *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = object->type == QStyleOptionRubberBand::Type;
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWidgets/QStyleOptionRubberBand_shell.cpp <==
#include "QStyleOptionRubberBand_shell.h"
#include <QtJambi/Cast>

void deleter_QStyleOptionRubberBand(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStyleOptionRubberBand")
    QStyleOptionRubberBand *_ptr = reinterpret_cast<QStyleOptionRubberBand *>(ptr);
    if(isShell){
        delete static_cast<QStyleOptionRubberBand_shell*>(_ptr);
    }else{
        QtJambiAPI::registerNonShellDeletion(ptr);
        delete _ptr;
    }
}

QtJambiShell* QStyleOptionRubberBand_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QStyleOptionRubberBand_shell) ); }

// emitting (writeShellDestructor)
QStyleOptionRubberBand_shell::~QStyleOptionRubberBand_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QStyleOptionRubberBand::~QStyleOptionRubberBand()", this)
    QStyleOptionRubberBand_shell::__shell()->destructed(typeid(QStyleOptionRubberBand));
}

// emitting (writeShellConstructor)
QStyleOptionRubberBand_shell::QStyleOptionRubberBand_shell()
    : QStyleOptionRubberBand()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStyleOptionRubberBand::QStyleOptionRubberBand_shell()", this)
    QStyleOptionRubberBand_shell::__shell()->constructed(typeid(QStyleOptionRubberBand));
}

QStyleOptionRubberBand_shell::QStyleOptionRubberBand_shell(const QStyleOptionRubberBand& other0)
    : QStyleOptionRubberBand(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStyleOptionRubberBand::QStyleOptionRubberBand_shell(const QStyleOptionRubberBand& other0)", this)
    QStyleOptionRubberBand_shell::__shell()->constructed(typeid(QStyleOptionRubberBand));
}

void QStyleOptionRubberBand_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QStyleOptionRubberBand_shell*>(ptr)->QStyleOptionRubberBand_shell::__shell()->tryDeleteShell(typeid(QStyleOptionRubberBand));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QStyleOptionRubberBand()
void __qt_construct_QStyleOptionRubberBand(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionRubberBand()")
    Q_UNUSED(__java_arguments)
    QStyleOptionRubberBand *__qt_this = new(__qtjambi_ptr) QStyleOptionRubberBand_shell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QStyleOptionRubberBand::QStyleOptionRubberBand()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionRubberBand_initialize_1native__Lio_qt_widgets_QStyleOptionRubberBand_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionRubberBand::QStyleOptionRubberBand()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionRubberBand, sizeof(QStyleOptionRubberBand_shell), typeid(QStyleOptionRubberBand), 0, true, &deleter_QStyleOptionRubberBand, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QStyleOptionRubberBand(QStyleOptionRubberBand)
void __qt_construct_QStyleOptionRubberBand_cref_QStyleOptionRubberBand(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionRubberBand(QStyleOptionRubberBand)")
    jobject other0 = __java_arguments[0].l;
    const QStyleOptionRubberBand& __qt_other0 = qtjambi_cast<const QStyleOptionRubberBand&>(__jni_env, other0);
    QStyleOptionRubberBand *__qt_this = new(__qtjambi_ptr) QStyleOptionRubberBand_shell(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QStyleOptionRubberBand::QStyleOptionRubberBand(QStyleOptionRubberBand)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionRubberBand_initialize_1native__Lio_qt_widgets_QStyleOptionRubberBand_2Lio_qt_widgets_QStyleOptionRubberBand_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionRubberBand::QStyleOptionRubberBand(QStyleOptionRubberBand)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionRubberBand_cref_QStyleOptionRubberBand, sizeof(QStyleOptionRubberBand_shell), typeid(QStyleOptionRubberBand), 0, true, &deleter_QStyleOptionRubberBand, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QStyleOptionRubberBand_shell
void __qt_destruct_QStyleOptionRubberBand(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStyleOptionRubberBand")
    reinterpret_cast<QStyleOptionRubberBand_shell*>(ptr)->~QStyleOptionRubberBand_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStyleOptionRubberBand::operator=(QStyleOptionRubberBand)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionRubberBand_assign_1native_1cref_1QStyleOptionRubberBand__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QStyleOptionRubberBand *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionRubberBand>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStyleOptionRubberBand::operator=(QStyleOptionRubberBand)", __this_nativeId)
        const QStyleOptionRubberBand& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QStyleOptionRubberBand>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionRubberBand_setOpaque_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean opaque0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionRubberBand *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionRubberBand>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->opaque = static_cast<bool>(opaque0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionRubberBand_opaque_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionRubberBand *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionRubberBand>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        bool  __qt_value = __qt_this->opaque;
        __java_return_value = jboolean(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionRubberBand_setShape_1native_1cref_1QRubberBand_1Shape__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint shape0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
#if QT_CONFIG(rubberband)
        QStyleOptionRubberBand *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionRubberBand>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QRubberBand::Shape __qt_shape0 = qtjambi_cast<QRubberBand::Shape>(__jni_env, shape0);
        __qt_this->shape = QRubberBand::Shape(__qt_shape0);
#else
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(shape0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif //QT_CONFIG(rubberband)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionRubberBand_shape_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
#if QT_CONFIG(rubberband)
        QStyleOptionRubberBand *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionRubberBand>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QRubberBand::Shape&  __qt_value = __qt_this->shape;
        __java_return_value = __qt_value;
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif //QT_CONFIG(rubberband)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionRubberBand_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStyleOptionRubberBand *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionRubberBand>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStyleOptionRubberBand(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStyleOptionRubberBand>("QStyleOptionRubberBand", "io/qt/widgets/QStyleOptionRubberBand");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QStyleOptionRubberBand, {
        ConstructorInfo(&__qt_construct_QStyleOptionRubberBand, nullptr)
       ,ConstructorInfo(&__qt_construct_QStyleOptionRubberBand_cref_QStyleOptionRubberBand, "Lio/qt/widgets/QStyleOptionRubberBand;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStyleOptionRubberBand);
    registerMetaType<QStyleOptionRubberBand>("QStyleOptionRubberBand");
    registerSizeOfShell(typeId, sizeof(QStyleOptionRubberBand_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QStyleOption), typeId, [](void *ptr, qintptr& offset) -> bool {
            QStyleOption *object = reinterpret_cast<QStyleOption *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = object->type == QStyleOptionRubberBand::Type;
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
